summaryrefslogtreecommitdiffstats
path: root/third_party/closure_compiler
diff options
context:
space:
mode:
authormtomasz <mtomasz@chromium.org>2015-02-18 02:25:11 -0800
committerCommit bot <commit-bot@chromium.org>2015-02-18 10:26:11 +0000
commitf4da3f0ba43a4fdefcdeb419e75b27f989eb11ec (patch)
tree77eee0a577654976c871c0250f67d81e3aa9e3de /third_party/closure_compiler
parenta628a42300fb022c51210395e2cf9bdda752ad39 (diff)
downloadchromium_src-f4da3f0ba43a4fdefcdeb419e75b27f989eb11ec.zip
chromium_src-f4da3f0ba43a4fdefcdeb419e75b27f989eb11ec.tar.gz
chromium_src-f4da3f0ba43a4fdefcdeb419e75b27f989eb11ec.tar.bz2
Respect list of requested properties in external metadata provider.
Before, we were always returning a thumbnail via getEntryProperties() as we never knew whether it was requested or not. This CL passes a list of requested properties from the new metadata logic to getEntryProperties(). Currently, Drive implementation ignores it, and FSP only cares whether the thumbnailUrl was requested or not. Support for more properties will be added in a separate CL. TEST=browser_tests: *FileSystemProvider*Thumbnail* BUG=408017 Review URL: https://codereview.chromium.org/927663003 Cr-Commit-Position: refs/heads/master@{#316796}
Diffstat (limited to 'third_party/closure_compiler')
-rw-r--r--third_party/closure_compiler/externs/file_manager_private.js23
1 files changed, 12 insertions, 11 deletions
diff --git a/third_party/closure_compiler/externs/file_manager_private.js b/third_party/closure_compiler/externs/file_manager_private.js
index 98c842d..6d68a50 100644
--- a/third_party/closure_compiler/externs/file_manager_private.js
+++ b/third_party/closure_compiler/externs/file_manager_private.js
@@ -16,19 +16,19 @@ var FileTask;
/**
* @typedef {{
- * fileSize: (number|undefined),
- * lastModifiedTime: (number|undefined),
+ * size: (number|undefined),
+ * modificationTime: (number|undefined),
* thumbnailUrl: (string|undefined),
* externalFileUrl: (string|undefined),
* imageWidth: (number|undefined),
* imageHeight: (number|undefined),
* imageRotation: (number|undefined),
- * isPinned: (boolean|undefined),
- * isPresent: (boolean|undefined),
- * isHosted: (boolean|undefined),
- * isDirty: (boolean|undefined),
- * isAvailableOffline: (boolean|undefined),
- * isAvailableWhenMetered: (boolean|undefined),
+ * pinned: (boolean|undefined),
+ * present: (boolean|undefined),
+ * hosted: (boolean|undefined),
+ * dirty: (boolean|undefined),
+ * availableOffline: (boolean|undefined),
+ * availableWhenMetered: (boolean|undefined),
* customIconUrl: (string|undefined),
* contentMimeType: (string|undefined),
* sharedWithMe: (boolean|undefined),
@@ -312,11 +312,12 @@ chrome.fileManagerPrivate.selectFile = function(selectedPath, index, forOpening,
/**
* Requests additional properties for files. |fileUrls| list of URLs of files
* |callback|
* @param {Array} fileUrls
* @param {Function} callback |entryProperties| A dictionary containing
* properties of the requested entries.
*/
-chrome.fileManagerPrivate.getEntryProperties = function(fileUrls, callback) {};
+chrome.fileManagerPrivate.getEntryProperties = function(fileUrls, names, callback) {};
/**
* Pins/unpins a Drive file in the cache. |fileUrl| URL of a file to pin/unpin.
@@ -312,11 +312,12 @@ chrome.fileManagerPrivate.selectFile = function(selectedPath, index, forOpening,
* Requests additional properties for files. |fileUrls| list of URLs of files
* |callback|
- * @param {Array} fileUrls
- * @param {Function} callback |entryProperties| A dictionary containing
+ * @param {!Array<string>} fileUrls
+ * @param {!Array<string>} names
+ * @param {!Function} callback |entryProperties| A dictionary containing
* properties of the requested entries.
*/